@@ -30,14 +30,14 @@ MDplot4multiplevectors = function(...,
   if (length(inputs) == 1) {
     if (is.list(inputs[[1]])) {
       #the list of input consists exactly of one list
-      df = do.call(what = addcols, inputs[[1]])#for every element of this list do
+      df = do.call(what = CombineCols, inputs[[1]])#for every element of this list do
     } else{
       #assumption: only one element ist given which is not a list, error catching if its not the case is done in base
       df = as.matrix(inputs[[1]])
     }
   } else{
     #several vectors are given, error catching if its not the case is done in (former) rowr
-    df = addcols(...)
+    df = CombineCols(...)
   }
   
   if (!missing(Names)) {
